package applications;

/*
 *  Copyright (C) 2014 - 2018 Juergen Platzer
 *
 *  This file is part of JFXLibrary.
 *
 *  JFXLibrary is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  JFXLibrary is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with JFXLibrary.  If not, see <http://www.gnu.org/licenses/>.
 */


import java.util.Hashtable;
import java.util.Vector;
import java.util.Enumeration;


import static applications.LanguageProperties.*;
import static applications.Settings.*;
import static applications.SettingsDialog.*;

/**
 * An entity that holds the default language properties, for example
 * all label names in English.
 **/
public class DefaultLanguageProperties {

  /** member variables **/
  private Hashtable<String, String> m_pProperties;

  /////////////////////////////////
  // CONSTRUCTOR                 //
  /////////////////////////////////
  /**
   *  Creates a language property object holding the default label name settings in English.
   */
  public DefaultLanguageProperties() {
    m_pProperties = new Hashtable<String, String>();

    //global names
    m_pProperties.put(KEY_APP_NAME, "JFXLibrary Gui Application");
    m_pProperties.put(KEY_OK, "OK");
    m_pProperties.put(KEY_ABORT, "Abort");


    //file menu
    m_pProperties.put(KEY_FILE_MENU, "File");
    m_pProperties.put(KEY_SAVE_IMAGE, "Save image");
    m_pProperties.put(KEY_EXIT, "Exit");

    //view menu
    m_pProperties.put(KEY_VIEW_MENU, "View");
    m_pProperties.put(KEY_VIEW_PROPERTIES_FRAME, "Show properties frame");




    //image effect menu
    m_pProperties.put(KEY_IMAGE_EFFECT_MENU, "Image effects");

    m_pProperties.put(KEY_TRANSFORMATION_MENU, "Transformations");
    m_pProperties.put(KEY_FRACTALS_MENU, "Fractals");
    m_pProperties.put(KEY_MANDELBROT_SET_MENU, "Mandelbrot set");
    m_pProperties.put(KEY_JULIA_SET_MENU, "Julia set");
    m_pProperties.put(KEY_JULIA_SET2_MENU, "Julia set (Select)");

    m_pProperties.put(KEY_RESIZE_MENU, "Resize");
    m_pProperties.put(KEY_DRAWING_MENU, "Drawing");
    m_pProperties.put(KEY_STARS_MENU, "Stars");
    m_pProperties.put(KEY_NETWORK_MENU, "Network");
    m_pProperties.put(KEY_BRICK_TEXTURE_MENU, "Brick texture");

    m_pProperties.put(KEY_COLOR_MENU, "Color");
    m_pProperties.put(KEY_GRAYSCALE_REDUCTION_MENU, "Grayscale reduction");
    m_pProperties.put(KEY_COLOR_TRANSITION_MENU, "Color transition");
    m_pProperties.put(KEY_NOISE_GENERATOR_MENU, "Noise generator");


    m_pProperties.put(KEY_TRANSPARENCY_MENU, "Transparency");
    m_pProperties.put(KEY_IMAGE_TRANSITION_MENU, "Image transition");

    //Configuration menu
    m_pProperties.put(KEY_CONFIGURATION_MENU, "Configuration");
    m_pProperties.put(KEY_SETTINGS_MENU, "Settings");


    ////////////////////
    //SETTINGS DIALOG
    m_pProperties.put(LANG_KEY_LANGUAGE, "Language:");

    ////////////////////
    //PROPERTIES FRAME
    m_pProperties.put("PropertyFrame.Title", "Effect properties");

    ////////////////////
    //ERRORS
    m_pProperties.put(KEY_ERROR, "Error");
    m_pProperties.put(KEY_ERROR_NO_IMAGE_TO_SAVE, "There is no image that can be saved!");

    ///////////////////
    // SAVE OPTIONS DIALOG
    m_pProperties.put(KEY_SAVE_OPTIONS_DIALOG_TITLE, "Save options");

    ////////////////////
    //IMAGE RESIZE
    //TODO: switch to constants
    m_pProperties.put("ImageResize.Image", "Image");
    m_pProperties.put("ImageResize.MaximumSide", "Maximum side");

    ///////////////////
    //STARS
    StarsLanguageProperties.addDefaultLanguageProperties(m_pProperties);


    ///////////////////
    //NETWORK
    NetworkLanguageProperties.addDefaultLanguageProperties(m_pProperties);




    ///////////////////
    //BRICK TEXTURE
    BrickTextureLanguageProperties.addDefaultLanguageProperties(m_pProperties);




    ///////////////////
    //FractalSet
    FractalSetLanguageProperties.addDefaultLanguageProperties(m_pProperties);

    ///////////////////
    //GrayscaleReduction
    GrayscaleReductionLanguageProperties.addDefaultLanguageProperties(m_pProperties);


    ///////////////////
    //ColorTransition
    ColorTransitionLanguageProperties.addDefaultLanguageProperties(m_pProperties);


    ///////////////////
    //NoiseGenerator
    NoiseGeneratorLanguageProperties.addDefaultLanguageProperties(m_pProperties);

    ///////////////////
    //ImageTransition
    //TODO: refactor to own file
    m_pProperties.put("ImageTransition.Images", "Images");
    m_pProperties.put("ImageTransition.TransitionCoordinates", "Transition coordinates");


    GuiLanguageProperties.addDefaultLanguageProperties(m_pProperties);


  }


  //////////////////////////////////
  // GET METHODS                  //
  //////////////////////////////////

  /**
   *  Returns the value of the specified property.
   *
   *  @param pProperty A string indicating the name of the property.
   *
   *  @return The value of the specified property as string.
   **/
  public String getProperty(String pProperty) {
    //1. make an initial check
    if (pProperty == null) return "";
    if (pProperty.trim().equals("")) return "";

    //2. return the value
    String pValue = m_pProperties.get(pProperty);
    if (pValue == null) return pProperty;
    return pValue;
  }

  public Vector<String> getPropertyNames() {
    Enumeration<String> pKeys = m_pProperties.keys();
    Vector<String> pVector = new Vector<String>();
    while (pKeys.hasMoreElements()) {
      pVector.add(pKeys.nextElement());
    }
    return pVector;
  }
}
