package applications;

/*
 *  Copyright (C) 2018 Juergen Platzer
 *
 *  This file is part of JFXLibrary.
 *
 *  JFXLibrary is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  JFXLibrary is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with JFXLibrary.  If not, see <http://www.gnu.org/licenses/>.
 */


import java.util.Hashtable;


/**
 * An entity that holds the default language properties, for example
 * all label names in English.
 **/
public abstract class FractalSetLanguageProperties {

  private static final String KEY_PREFIX = "FractalSet.";




  public static final String KEY_ITERATION_DEPTH = KEY_PREFIX + "IterationDepth";
  public static final String KEY_COLOR_GRADIENT = KEY_PREFIX + "ColorGradient";
  public static final String KEY_SIZE = KEY_PREFIX + "Size";
  public static final String KEY_NAVIGATION = KEY_PREFIX + "Navigation";
  public static final String KEY_NAVIGATION2 = KEY_PREFIX + "Navigation2";
  public static final String KEY_RESET = KEY_PREFIX + "Reset";
  public static final String KEY_LEFT_UPPER_CORNER = KEY_PREFIX + "LeftUpperCorner";
  public static final String KEY_RIGHT_LOWER_CORNER = KEY_PREFIX + "RightLowerCorner";
  public static final String KEY_MOVE_LEFT = KEY_PREFIX + "MoveLeft";
  public static final String KEY_MOVE_RIGHT = KEY_PREFIX + "MoveRight";
  public static final String KEY_MOVE_UP = KEY_PREFIX + "MoveUp";
  public static final String KEY_MOVE_DOWN = KEY_PREFIX + "MoveDown";
  public static final String KEY_MOVE_STEP_SIZE = KEY_PREFIX + "StepSize";


  public static final String KEY_PARAMETER_C = KEY_PREFIX + "ParameterC";
  public static final String KEY_PARAMETER_REAL = KEY_PREFIX + "Real";
  public static final String KEY_PARAMETER_IMAGINARY = KEY_PREFIX + "Imaginary";


  public static final String KEY_MANDELBROT_SET = KEY_PREFIX + "MandelbrotSet";
  public static final String KEY_JULIA_SET = KEY_PREFIX + "JuliaSet";

  public static final String KEY_SAVE_JULIA_SET = KEY_PREFIX + "SaveJuliaSet";
  public static final String KEY_SAVE_MANDELBROT_SET = KEY_PREFIX + "SaveMandelbrotSet";
  public static final String KEY_SAVE_JULIA_MB_EXCEPTION = KEY_PREFIX + "SaveJuliaMBException";



  public static void addDefaultLanguageProperties(Hashtable<String, String> pProperties) {
    if (pProperties == null) return;

    pProperties.put(KEY_ITERATION_DEPTH, "Iteration depth");
    pProperties.put(KEY_COLOR_GRADIENT, "Color gradient");
    pProperties.put(KEY_SIZE, "Size");
    pProperties.put(KEY_NAVIGATION, "Navigation");
    pProperties.put(KEY_NAVIGATION2, "Navigation 2");

    pProperties.put(KEY_RESET, "Reset Mandelbrot set");
    pProperties.put(KEY_LEFT_UPPER_CORNER, "Left upper corner:");
    pProperties.put(KEY_RIGHT_LOWER_CORNER, "Right lower corner:");

    pProperties.put(KEY_MOVE_LEFT, "Move left");
    pProperties.put(KEY_MOVE_RIGHT, "Move right");
    pProperties.put(KEY_MOVE_UP, "Move up");
    pProperties.put(KEY_MOVE_DOWN, "Move down");
    pProperties.put(KEY_MOVE_STEP_SIZE, "Step size:");

    pProperties.put(KEY_PARAMETER_C, "Parameter C");
    pProperties.put(KEY_PARAMETER_REAL, "Real");
    pProperties.put(KEY_PARAMETER_IMAGINARY, "Imaginary");


    pProperties.put(KEY_MANDELBROT_SET, "Mandelbrot set");
    pProperties.put(KEY_JULIA_SET, "Julia set");

    pProperties.put(KEY_SAVE_JULIA_SET, "Save Julia set");
    pProperties.put(KEY_SAVE_MANDELBROT_SET, "Save Mandelbrot set");
    pProperties.put(KEY_SAVE_JULIA_MB_EXCEPTION, "Either the Julia set or the Mandelbrot set has to be selected!");


  }
}
