package applications;

/*
 *  Copyright (C) 2018 Juergen Platzer 
 * 
 *  This file is part of JFXLibrary.
 *  
 *  JFXLibrary is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *  
 *  JFXLibrary is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *  
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with JFXLibrary.  If not, see <http://www.gnu.org/licenses/>.
 */

//menu imports
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JMenu;
import javax.swing.KeyStroke;
import javax.swing.JCheckBoxMenuItem;
 
 
//event imports
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.awt.event.KeyEvent;


//library imports
import gui.AbstractImageEffectPanel;
import gui.SimpleImageEffectPanel;
import gui.drawing.StarsPanel;
import gui.fractals.MandelbrotSetPanel;
import gui.fractals.JuliaSetPanel;
import gui.fractals.JuliaSetWithMandelbrotPanel;

import color.ColorTransition;
import color.GrayscaleReduction;
import color.NoiseGenerator;
import transformation.ImageResize;
import drawing.Network;
import drawing.BrickTexture;
import transparency.ImageTransition;

import static applications.LanguageProperties.*;
import static applications.Settings.*;


public class GuiApplicationMenu implements ActionListener, ISettingsListener {

  /*** gui member variables ***/
  private JMenuBar m_pMenuBar;
  private JMenu m_pFileMenu, m_pViewMenu, m_pImageEffectMenu, m_pFractalsMenu;
  private JMenu m_pTransformationMenu, m_pDrawingMenu, m_pColorMenu, m_pConfigurationMenu;
  private JMenu m_pTransparencyMenu;
  private JMenuItem m_pSaveMenu, m_pExitMenu, m_pMandelbrotSet, m_pJuliaSet, m_pJuliaSet2, m_pStars, m_pNetwork, m_pSettingsMenu;
  private JMenuItem m_pGrayscaleReduction, m_pColorTransition, m_pBrickTexture, m_pResizeMenu;
  private JMenuItem m_pNoiseGenerator, m_pImageTransition;
  private JCheckBoxMenuItem m_pViewPropertiesFrame;
  
  /*** other members ***/
  private GuiApplication m_pApplication;
  
  
  
  
  
  ////////////////////////////////
  // CONSTRUCTOR                //
  ////////////////////////////////
  public GuiApplicationMenu(GuiApplication pApplication) {
    //0. set other members
    m_pApplication = pApplication;
    
    //1. create the menu bar
    m_pMenuBar = new JMenuBar();

    
    //2. file menu
    m_pFileMenu = new JMenu();
    m_pSaveMenu = new JMenuItem();
    m_pSaveMenu.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_S, ActionEvent.CTRL_MASK));
    m_pSaveMenu.addActionListener(this);
    m_pFileMenu.add(m_pSaveMenu);
    
    m_pExitMenu = new JMenuItem();
    m_pExitMenu.addActionListener(this);
    m_pFileMenu.addSeparator();
    m_pFileMenu.add(m_pExitMenu);
    
    //3. view menu
    m_pViewMenu = new JMenu();
    m_pViewPropertiesFrame = new JCheckBoxMenuItem();
    m_pViewPropertiesFrame.setSelected(true);
    m_pViewPropertiesFrame.addActionListener(this);
    m_pViewMenu.add(m_pViewPropertiesFrame);
    
    //4. image effects
    m_pImageEffectMenu = new JMenu();
    
    m_pTransformationMenu = new JMenu();
    m_pResizeMenu = new JMenuItem();
    m_pResizeMenu.addActionListener(this);
    m_pTransformationMenu.add(m_pResizeMenu);
    m_pImageEffectMenu.add(m_pTransformationMenu);
    
    m_pFractalsMenu = new JMenu();
    m_pMandelbrotSet = new JMenuItem();
    m_pMandelbrotSet.addActionListener(this);
    m_pFractalsMenu.add(m_pMandelbrotSet);
    
    m_pJuliaSet = new JMenuItem();
    m_pJuliaSet.addActionListener(this);
    m_pFractalsMenu.add(m_pJuliaSet);
    
    m_pJuliaSet2 = new JMenuItem();
    m_pJuliaSet2.addActionListener(this);
    m_pFractalsMenu.add(m_pJuliaSet2);
    m_pImageEffectMenu.add(m_pFractalsMenu);
    
    
    
    
    m_pDrawingMenu = new JMenu();
    m_pStars = new JMenuItem();
    m_pStars.addActionListener(this);
    m_pDrawingMenu.add(m_pStars);
    
    m_pNetwork = new JMenuItem();
    m_pNetwork.addActionListener(this);
    m_pDrawingMenu.add(m_pNetwork);

    m_pBrickTexture = new JMenuItem();
    m_pBrickTexture.addActionListener(this);
    m_pDrawingMenu.add(m_pBrickTexture);
    m_pImageEffectMenu.add(m_pDrawingMenu);
    
    
    m_pColorMenu = new JMenu();
    m_pGrayscaleReduction = new JMenuItem();
    m_pGrayscaleReduction.addActionListener(this);
    m_pColorMenu.add(m_pGrayscaleReduction);
    
    m_pColorTransition = new JMenuItem();
    m_pColorTransition.addActionListener(this);
    m_pColorMenu.add(m_pColorTransition);
    
    m_pNoiseGenerator = new JMenuItem();
    m_pNoiseGenerator.addActionListener(this);
    m_pColorMenu.add(m_pNoiseGenerator);
    m_pImageEffectMenu.add(m_pColorMenu);
    
    
    m_pTransparencyMenu = new JMenu();
    m_pImageTransition = new JMenuItem();
    m_pImageTransition.addActionListener(this);
    m_pTransparencyMenu.add(m_pImageTransition);
    m_pImageEffectMenu.add(m_pTransparencyMenu);
    
    
    
    //4. configuration menu
    m_pConfigurationMenu = new JMenu();
    m_pSettingsMenu = new JMenuItem();
    m_pSettingsMenu.addActionListener(this);
    m_pConfigurationMenu.add(m_pSettingsMenu);
    
    //finally add all menus to the menubar
    m_pMenuBar.add(m_pFileMenu);
    m_pMenuBar.add(m_pViewMenu);
    m_pMenuBar.add(m_pImageEffectMenu);
    m_pMenuBar.add(m_pConfigurationMenu);
  }
  
  
  //////////////////////////////
  // GET METHODS              //
  //////////////////////////////
  public JMenuBar getMenuBar() {
    return m_pMenuBar;
  }
  
  public boolean showProperties() {
    return m_pViewPropertiesFrame.isSelected();
  }
  
  
  
  /////////////////////////////////////////
  // ACTION LISTENER                     //
  /////////////////////////////////////////
  /**
   *  Implementation of the {@code ActionListener} interface to react on menu actions or changes in the settings.
   *
   *  @param e The {@code ActionEvent} from which the source of the action is fetched.
   **/
  public void actionPerformed(ActionEvent e) {
    String pActionCommand = e.getActionCommand();
    Object pSource = e.getSource();
    if (m_pApplication == null) return;
    
    
    //1. the exit
    if (pSource.equals(m_pExitMenu)) {
      System.exit(0);
    }
    
    
    //2. the options
    if (pSource.equals(m_pSettingsMenu)) {
      
      m_pApplication.showSettingsDialog();
      
      return;
    }
    
    //3. save some images
    if (pSource.equals(m_pSaveMenu)) {
      
      m_pApplication.saveCurrentEffectImage();
      return;
      
    }
    
    
    //4. show properties frame
    if (pSource.equals(m_pViewPropertiesFrame)) {
      m_pApplication.showPropertiesPanel(m_pViewPropertiesFrame.isSelected());
      return;
      
 
    }
    
    //5. create an effect image, because this is the fun, it is about
    AbstractImageEffectPanel pPanel = null;
    if (pSource.equals(m_pMandelbrotSet)) {
      pPanel = new MandelbrotSetPanel();
    }
    else if (pSource.equals(m_pJuliaSet)) {
      pPanel = new JuliaSetPanel();
    }
    else if (pSource.equals(m_pJuliaSet2)) {
      pPanel = new JuliaSetWithMandelbrotPanel();
    }
    else if (pSource.equals(m_pStars)) {
      pPanel = new StarsPanel();
    }
    else if (pSource.equals(m_pNetwork)) {
      pPanel = new SimpleImageEffectPanel(new Network());
    }
    else if (pSource.equals(m_pBrickTexture)) {
      pPanel = new SimpleImageEffectPanel(new BrickTexture());
    }
    else if (pSource.equals(m_pGrayscaleReduction)) {
      pPanel = new SimpleImageEffectPanel(new GrayscaleReduction());
    }
    else if (pSource.equals(m_pColorTransition)) {
      //to do load an image -> FileLoadPanel = only for the effect properties panel
      pPanel = new SimpleImageEffectPanel(new ColorTransition());
    }
    else if (pSource.equals(m_pNoiseGenerator)) {
      pPanel = new SimpleImageEffectPanel(new NoiseGenerator());
    }
    else if (pSource.equals(m_pResizeMenu)) {
      pPanel = new SimpleImageEffectPanel(new ImageResize());
    }
    else if (pSource.equals(m_pImageTransition)) {
      pPanel = new SimpleImageEffectPanel(new ImageTransition());
    }
    
    
    m_pApplication.setImageEffectPanel(pActionCommand, pPanel);
  }
  
  
  ////////////////////////////////////
  // ISettingsListener METHODS      //
  ////////////////////////////////////
  
  /**
   *  Apply the changes of the settings to the application. For example when the language is changed, 
   *  all GUI elements are updated accordingly.
   *
   *  @param pSettings The new {@code Settings} object that is used to retrieve all labels. 
   **/
  public void applyNewSettings(Settings pSettings) {
    //1. make an initial check and set the settings
    if (pSettings == null) return;
    
    //2. load new language settings
    LanguageProperties pLanguageProperties = pSettings.getLanguageProperties();
    
    
    //3. set all menu labels
    m_pFileMenu.setText(pLanguageProperties.getProperty(KEY_FILE_MENU));
    m_pSaveMenu.setText(pLanguageProperties.getProperty(KEY_SAVE_IMAGE));
    m_pExitMenu.setText(pLanguageProperties.getProperty(KEY_EXIT));
    
    m_pViewMenu.setText(pLanguageProperties.getProperty(KEY_VIEW_MENU));
    m_pViewPropertiesFrame.setText(pLanguageProperties.getProperty(KEY_VIEW_PROPERTIES_FRAME));

    
    m_pImageEffectMenu.setText(pLanguageProperties.getProperty(KEY_IMAGE_EFFECT_MENU));
    
    m_pTransformationMenu.setText(pLanguageProperties.getProperty(KEY_TRANSFORMATION_MENU));
    m_pResizeMenu.setText(pLanguageProperties.getProperty(KEY_RESIZE_MENU));
    
    m_pFractalsMenu.setText(pLanguageProperties.getProperty(KEY_FRACTALS_MENU));
    m_pMandelbrotSet.setText(pLanguageProperties.getProperty(KEY_MANDELBROT_SET_MENU));
    m_pJuliaSet.setText(pLanguageProperties.getProperty(KEY_JULIA_SET_MENU));
    m_pJuliaSet2.setText(pLanguageProperties.getProperty(KEY_JULIA_SET2_MENU));
    
    
    m_pDrawingMenu.setText(pLanguageProperties.getProperty(KEY_DRAWING_MENU));
    m_pStars.setText(pLanguageProperties.getProperty(KEY_STARS_MENU));
    m_pNetwork.setText(pLanguageProperties.getProperty(KEY_NETWORK_MENU));
    m_pBrickTexture.setText(pLanguageProperties.getProperty(KEY_BRICK_TEXTURE_MENU));
    
    m_pColorMenu.setText(pLanguageProperties.getProperty(KEY_COLOR_MENU));
    m_pGrayscaleReduction.setText(pLanguageProperties.getProperty(KEY_GRAYSCALE_REDUCTION_MENU));
    m_pColorTransition.setText(pLanguageProperties.getProperty(KEY_COLOR_TRANSITION_MENU));
    m_pNoiseGenerator.setText(pLanguageProperties.getProperty(KEY_NOISE_GENERATOR_MENU));
    
    m_pTransparencyMenu.setText(pLanguageProperties.getProperty(KEY_TRANSPARENCY_MENU));
    m_pImageTransition.setText(pLanguageProperties.getProperty(KEY_IMAGE_TRANSITION_MENU));
    
    m_pConfigurationMenu.setText(pLanguageProperties.getProperty(KEY_CONFIGURATION_MENU));
    m_pSettingsMenu.setText(pLanguageProperties.getProperty(KEY_SETTINGS_MENU));
    
  }
  
  
  


}