package color;

/*
 *  Copyright (C) 2014 Juergen Platzer 
 * 
 *  This file is part of JFXLibrary.
 *  
 *  JFXLibrary is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *  
 *  JFXLibrary is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *  
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with JFXLibrary.  If not, see <http://www.gnu.org/licenses/>.
 */

//standard imports
import java.util.Hashtable;

//library imports
import standard.EffectParameters;
import standard.IntegerParameter;
import standard.ObjectParameter;
import util.image.ExampleImageGenerator;

/**
 *   Encapsulates the parameters that can be specified for the {@code GrayscaleReduction} object. 
 **/
public class GrayscaleReductionParameters extends EffectParameters {

  /*** PUBLIC PARAMETER KEYS ***/

  /*** KEY for the integer parameter: number of grayscales  ***/
  public static final String PARAM_INT_GRAYSCALENUM = "GRAYSCALENUM";
  
  
  /*** KEY for the object parameter: image ***/
  public static final String PARAM_OBJECT_IMAGE = "IMAGE";
    
   /***
   *   Creates a default parameter set for the GrayscaleReduction effect. The following settings are used:
   *
   *   <ul>
   *     <li>An empty image with the dimension 400 x 400 pixels</li>
   *     <li>8 grayscales</li>
   *   </ul>
   *
   **/
  public GrayscaleReductionParameters() {

    //1. create the parameters and set them
    setIntegerParameters(createIntegerParameters());
    setObjectParameters(createObjectParameters());

  }
  
  
  ////////////////////////////////////////////
  // PRIVATE METHODS FOR PARAMETER CREATION //
  ////////////////////////////////////////////
  private Hashtable<String, IntegerParameter> createIntegerParameters() {
    //1. create the hashtable
    Hashtable<String, IntegerParameter> pParameters = new Hashtable<String, IntegerParameter>();

    //2. fill the hashtable
    pParameters.put(PARAM_INT_GRAYSCALENUM, new IntegerParameter(8, 1, 255));
    
    //3. return the hashtable
    return pParameters;
  }
  
  
  
  private Hashtable<String, ObjectParameter> createObjectParameters() {
    //1. create the hashtable
    Hashtable<String, ObjectParameter> pParameters = new Hashtable<String, ObjectParameter>();

    //2. fill the hashtable
    ExampleImageGenerator pGenerator = new ExampleImageGenerator();
    pParameters.put(PARAM_OBJECT_IMAGE, new ObjectParameter(pGenerator.getImage()));
  
    //3. return the hashtable
    return pParameters;
  }
  
}
  
  
  
