package drawing;

/*
 *  Copyright (C) 2014 Juergen Platzer 
 * 
 *  This file is part of JFXLibrary.
 *  
 *  JFXLibrary is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *  
 *  JFXLibrary is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *  
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with JFXLibrary.  If not, see <http://www.gnu.org/licenses/>.
 */

import java.awt.Point;

/**
 *  A helper class for the {@code Network} effect, representing a node in the network image.
 **/

public class NetworkNode extends Point{
  
  /*** member variables ***/
  private int m_iPointSize;
  
  
  /**
   *  Creates a {@code NetworkNode} object at the specified x and y position.
   *  A point size of 1 is set.
   *
   *  @param x The x (horizontal) position of the node. 
   *  @param y The y (vertical) position of the node. 
   **/
  public NetworkNode(int x, int y) {
    super(x, y);
    m_iPointSize = 1;
  }
  
  /**
   *  Increases the point size by 1
   *
   **/
  public void increasePointSize() {
    m_iPointSize++;
  }
  
  
  /**
   *  Returns the point size as integer.
   *
   *  @return The point size as integer.
   **/
  public int getPointSize() {
    return m_iPointSize;
  }
}
