package fractals;

/*
 *  Copyright (C) 2014 - 2018 Juergen Platzer 
 * 
 *  This file is part of JFXLibrary.
 *  
 *  JFXLibrary is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *  
 *  JFXLibrary is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *  
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with JFXLibrary.  If not, see <http://www.gnu.org/licenses/>.
 */

//standard imports
import java.util.Hashtable;

//library imports
import util.math.ComplexNumber;

/**
 *   Encapsulates the parameters that can be specified for the MandelbrotSet object. 
 **/
public class MandelbrotSetParameters extends FractalSetParameters {

  
    
   /***
   *   Creates a default parameter set for the fractals iterator so that it create a Mandelbrot set. The following settings are used:
   *
   *   <ul>
   *     <li>iteration depth: 100</li>
   *     <li>width x height: 400 x 400</li>
   *     <li>decision limit: 2</li>
   *     <li>upper left window corner: (-2, 1.5)</li>
   *     <li>lower right window corner: (1, -1.5)</li>
   *     <li>z: (0,0)</li>
   *     <li>Color gradient: From White to Black</li>
   *   </ul>
   *
   **/
  public MandelbrotSetParameters() {

    createParameters();
  }
  
  
  
  
  
  //////////////////////////////
  // CHANGE METHODS           //
  //////////////////////////////
 
  
  
  /**
   *  Sets the effect back to the default settings.
   **/
  public void setDefaultMandelbrotSet() {
   setDefaultFractalSet();
  }
  
  //////////////////////////////
  // GET METHODS              //
  //////////////////////////////
 
  
   ///////////////////////////////
  // PROTECTED METHODS         //
  ///////////////////////////////
  protected ComplexNumber getDefaultUpperLeftWindowCorner() {
    return new ComplexNumber(-2, 1.5);
  }
  
  protected ComplexNumber getDefaultLowerRightWindowCorner() {
    return new ComplexNumber(1, -1.5);
  }
  
  protected Hashtable<String, ComplexNumber> getComplexNumberParameters() {
  //1. create the hashtable
    Hashtable<String, ComplexNumber> pParameters = new Hashtable<String, ComplexNumber>();
    
    pParameters.put(PARAM_OBJECT_COMPLEX_NUMBER_Z, new ComplexNumber(0,0));

    
    //3. return the hashtable
    return pParameters;
  }
  
 
}
  
  
  
