package gui;

/*
 *  Copyright (C) 2018 Juergen Platzer 
 * 
 *  This file is part of JFXLibrary.
 *  
 *  JFXLibrary is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *  
 *  JFXLibrary is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *  
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with JFXLibrary.  If not, see <http://www.gnu.org/licenses/>.
 */


import java.text.DecimalFormat;



/**
 *  A panel for steering a numeric effect parameter with a slider and a spinner as main gui components.
 **/
public class DoubleSliderPanel extends SliderPanel {

  
  private DecimalFormat m_pNumberFormat;
  
  ///////////////////////////////
  // CONSTRUCTOR               //
  ///////////////////////////////
  /**
   *  Creates the {@code SliderPanel} object with the specified minimum and maximum value and the given current value.
   *
   *  @param iMin The minimum value of the effect parameter.
   *  @param iMax The maximum value of the effect parameter.
   *  @param iCurrentValue The current value of the effect parameter.
   **/
  public DoubleSliderPanel(double dMin, double dMax, double dCurrentValue, double dStepSize) {
    m_pNumberFormat = new DecimalFormat("#0.###");
    initPanel(dMin, dMax, dCurrentValue, dStepSize);
  }
  
  ////////////////////////////////////
  // PROTECTED METHODS TO IMPLEMENT //
  ////////////////////////////////////
  protected String getMinMaxLabel(double dValue) {
    return m_pNumberFormat.format(dValue);
  }
  
  
  
  
 
 
  
  
 
}