package gui.fractals;

/*
 *  Copyright (C) 2018 Juergen Platzer 
 * 
 *  This file is part of JFXLibrary.
 *  
 *  JFXLibrary is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *  
 *  JFXLibrary is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *  
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with JFXLibrary.  If not, see <http://www.gnu.org/licenses/>.
 */



//library imports
import fractals.JuliaSet;
import fractals.JuliaSetParameters;
import gui.AbstractPropertiesPanel;



/**
 *  Handles the interaction with a Mandelbrot set.
 **/

public class JuliaSetPanel extends FractalSetPanel {

  
 
  private JuliaSetPropertiesPanel m_pPropertiesPanel;
  private JuliaSetParameters m_pParameters;
  
  
  ////////////////////////////////////
  // CONSTRUCTOR                    //
  ////////////////////////////////////
  /**
   *  Creates a {@code MandelbrotSetPanel} object with the default settings for the Mandelbrot set effect.
   **/
  public JuliaSetPanel() {
    
    m_pPropertiesPanel = null;
    m_pParameters = new JuliaSetParameters();
    initPanel(m_pParameters, new JuliaSet());
  }
  
  
  /////////////////////////
  // GET METHODS         //
  /////////////////////////
  /**
   *  Returns the {@code MandelbrotSetPropertiesPanel} object representing the effect parameters and providing a GUI to modify them.
   *
   *  @return The {@code MandelbrotSetPropertiesPanel} object representing the effect parameters and providing a GUI to modify them.
   **/
  public AbstractPropertiesPanel getPropertiesPanel() {
    if (m_pPropertiesPanel == null) {
      m_pPropertiesPanel = new JuliaSetPropertiesPanel(this);
    }
    
    return m_pPropertiesPanel;
  }
  
  ///////////////////////////
  // SET METHODS           //
  ///////////////////////////
  public void setCParameter(double dReal, double dImaginary) {
    m_pParameters.setCParameter(dReal, dImaginary);
     parametersChanged();
  }

  
 

}