package gui.fractals;

/*
 *  Copyright (C) 2018 Juergen Platzer
 *
 *  This file is part of JFXLibrary.
 *
 *  JFXLibrary is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  JFXLibrary is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with JFXLibrary.  If not, see <http://www.gnu.org/licenses/>.
 */

//gui imports
import java.awt.FlowLayout;
import java.awt.Dimension;



//Library imports
import gui.JPanelWithListener;
import gui.IImageEffectPanelListener;
import gui.SliderPanel;
import gui.DoubleSliderPanel;
import gui.ISliderPanelListener;

import util.math.ComplexNumber;


import applications.Settings;
import applications.SettingsDialog;
import applications.ISettingsListener;
import applications.LanguageProperties;

import static applications.FractalSetLanguageProperties.*;

/**
 *  A properties panel for the mandelbrot effect.
 **/
public class JuliaSetParameterCPanel
  extends JPanelWithListener<IJuliaSetParameterCPanelListener>
  implements ISettingsListener, ISliderPanelListener
   {

  /*** member variables ***/
  private DoubleSliderPanel m_pCReal, m_pCImaginary;


  ///////////////////////////////
  // CONSTRUCTOR               //
  ///////////////////////////////
  public JuliaSetParameterCPanel() {
    createPanel();


    Settings pSettings = SettingsDialog.getSettings();
    LanguageProperties pLanguageProperties = pSettings.getLanguageProperties();

    setLabels(pLanguageProperties);

  }




  ///////////////////////////
  // SET METHODS           //
  ///////////////////////////

  public void setParameterC(double dReal, double dImaginary) {
    m_pCReal.setDoubleValue(dReal);
    m_pCImaginary.setDoubleValue(dImaginary);

  }

  ////////////////////////////////
  // SLIDER PANEL LISTENER      //
  ////////////////////////////////
  public void applyChanges(SliderPanel pSliderPanel, int iValue, double dValue) {
    applyChanges();
  }

  ////////////////////////////////
  // LISTENER METHODS           //
  ////////////////////////////////



  protected void applyChangesToListener(IJuliaSetParameterCPanelListener pListener) {
    double dReal = m_pCReal.getDoubleValue();
    double dImaginary = m_pCImaginary.getDoubleValue();
    pListener.setParameterC(this, dReal, dImaginary);
  }














  ////////////////////////////////
  // SETTINGS LISTENER METHODS  //
  ////////////////////////////////
  /**
   *  Applies the changes of the settings to the application. For example when the language is changed,
   *  all GUI elements are updated accordingly.
   *
   *  @param pSettings The new {@code Settings} object that is used to retrieve all labels.
   **/
  public void applyNewSettings(Settings pSettings) {

    //1. make an initial check and set the settings
    if (pSettings == null) return;

    //2. load new language settings
    LanguageProperties pLanguageProperties = pSettings.getLanguageProperties();
    setLabels(pLanguageProperties);


  }


  public void setLabels(LanguageProperties pLanguageProperties) {
    m_pCReal.setLabelText(pLanguageProperties.getProperty(KEY_PARAMETER_REAL));
    m_pCImaginary.setLabelText(pLanguageProperties.getProperty(KEY_PARAMETER_IMAGINARY));
  }


  //////////////////////////////////
  // PRIVATE HELPER METHODS       //
  //////////////////////////////////





  private void createPanel() {
    setLayout(new FlowLayout());

    m_pCReal = new DoubleSliderPanel(-3, 3, 0, 0.01);
    m_pCReal.addPanelListener(this);
    add(m_pCReal);

    m_pCImaginary = new DoubleSliderPanel(-3, 3, 0, 0.01);
    m_pCImaginary.addPanelListener(this);
    add(m_pCImaginary);

  }


}
