package io.imageeffects;

/*
 *  Copyright (C) 2014 Juergen Platzer 
 * 
 *  This file is part of JFXLibrary.
 *  
 *  JFXLibrary is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *  
 *  JFXLibrary is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *  
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with JFXLibrary.  If not, see <http://www.gnu.org/licenses/>.
 */

import java.util.Enumeration;

//library imports
import standard.BooleanParameter;
import standard.IntegerParameter;
import standard.DoubleParameter;
import standard.ColorParameter;
import drawing.Stars;
import drawing.StarsParameters;
import io.Configuration;

/**
 *  Provides methods to read in configuration files to define a Stars image effect.
 **/

public class StarsConfiguration {


  public static final String EFFECT_PREFIX = "stars";

  /**
   *  Creates a {@code Stars} object from a configuration file. Exception messages by configuring the image effect object
   *  are written to the command line.
   *
   *  @param pConfiguration The configuration object that handles the direct access to the configuration file. 
   *
   *  @throws NullPointerException when no configuration object has been specified.

   *
   *  @return The {@code Stars} object that is represents the image effect defined by the settings of the specified configuration file.
   **/  

  public static Stars getEffect(Configuration pConfiguration) throws NullPointerException {
    //1. make a simple check
    if (pConfiguration == null) throw new NullPointerException("No configuration was specified!");
    
      
       
    //2. fetch and set the configuration values in the stars parameters
    StarsParameters pParams = new StarsParameters();
    
    //2.1. boolean parameters
    Enumeration<String> pBooleanParameters = pParams.getBooleanParameterNames();
    if (pBooleanParameters != null) {
      while (pBooleanParameters.hasMoreElements()) {
        String pParamName = pBooleanParameters.nextElement();
        String pConfigParamName = EFFECT_PREFIX + "." + pParamName;
        try {
          BooleanParameter pParam = pConfiguration.getBooleanParameter(pConfigParamName);
          pParams.setBooleanParameterValue(pParamName, pParam.getValue());
          System.out.println("Parameter " + pParamName + " was set!");
        }
        catch (Exception pException) {
          System.out.println("Parameter " + pParamName + " was NOT set! " + pException.getMessage());
        }
      }
    }
    
    
    //2.2. integer parameters
    Enumeration<String> pIntegerParameters = pParams.getIntegerParameterNames();
    if (pIntegerParameters != null) {
      while (pIntegerParameters.hasMoreElements()) {
        String pParamName = pIntegerParameters.nextElement();
        String pConfigParamName = EFFECT_PREFIX + "." + pParamName;
        try {
          IntegerParameter pParam = pConfiguration.getIntegerParameter(pConfigParamName);
          pParams.setIntegerParameterValue(pParamName, pParam.getValue());
          System.out.println("Parameter " + pParamName + " was set!");
        }
        catch (Exception pException) {
          System.out.println("Parameter " + pParamName + " was NOT set! " + pException.getMessage());
        }
      }
    }
    
    
    //2.1. double parameters
    Enumeration<String> pDoubleParameters = pParams.getDoubleParameterNames();
    if (pDoubleParameters != null) {
      while (pDoubleParameters.hasMoreElements()) {
        String pParamName = pDoubleParameters.nextElement();
        String pConfigParamName = EFFECT_PREFIX + "." + pParamName;
        try {
          DoubleParameter pParam = pConfiguration.getDoubleParameter(pConfigParamName);
          pParams.setDoubleParameterValue(pParamName, pParam.getValue());
          System.out.println("Parameter " + pParamName + " was set!");
        }
        catch (Exception pException) {
          System.out.println("Parameter " + pParamName + " was NOT set! " + pException.getMessage());
        }
      }
    }
    
    
    
    //2.1. color parameters
    Enumeration<String> pColorParameters = pParams.getColorParameterNames();
    if (pColorParameters != null) {
      while (pColorParameters.hasMoreElements()) {
        String pParamName = pColorParameters.nextElement();
        String pConfigParamName = EFFECT_PREFIX + "." + pParamName;
        try {
          ColorParameter pParam = pConfiguration.getColorParameter(pConfigParamName);
          pParams.setColorParameterValue(pParamName, pParam.getValue());
          System.out.println("Parameter " + pParamName + " was set!");
        }
        catch (Exception pException) {
          System.out.println("Parameter " + pParamName + " was NOT set! " + pException.getMessage());
        }
      }
    }
    
    return new Stars(pParams);
    
  }
  
}