package standard;

/*
 *  Copyright (C) 2014 Juergen Platzer 
 * 
 *  This file is part of JFXLibrary.
 *  
 *  JFXLibrary is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *  
 *  JFXLibrary is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *  
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with JFXLibrary.  If not, see <http://www.gnu.org/licenses/>.
 */

//standard imports
import java.awt.Color;

import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;

import java.util.Hashtable;

//library imports
//import gui.util.ColorChoosePanel;

/**
 *  Represents an image or video effect parameter that has a color value. 
 **/
public class ColorParameter implements IParameter, ActionListener {


  //private ColorChoosePanel m_pColorChoosePanel;
  private InterpolationContainer<InterpolatedColor> m_pInterpolationContainer;

  
  

  /////////////////////////
  // CONSTRUCTOR         //
  /////////////////////////
  /**
   *  Creates a {@code ColorParameter} object with the specified color value. 
   *
   * @param pColor The color value that should be represented by this {@code ColorParameter} object.
   **/
  public ColorParameter(Color pColor) {

    //1. set the member variables
    m_pInterpolationContainer = new InterpolationContainer<InterpolatedColor>();
    
    if (pColor == null) pColor = Color.BLACK;
    setValue(pColor);
    
    //m_pColorChoosePanel = null;
  }



  /////////////////////////
  // SET METHODS         //
  /////////////////////////
  /**
   * Sets the color value that should be represented by this {@code ColorParameter} object.
   *
   * @param pColor The color value that should be represented by this {@code ColorParameter} object.
   **/   
  public void setValue(Color pColor) {
    if (pColor ==null) return;
    
    m_pInterpolationContainer.setValue(new InterpolatedColor(pColor), 0);
    
    //if (m_pColorChoosePanel != null) m_pColorChoosePanel.setColor(pColor);

  }
  
  
  /**
   * Sets the color value that should be represented by this {@code ColorParameter} object.
   * The color value is representated by a string. The rgb values can be specified separated by commas. Also 
   * default colors like black, blue, cyan can be specified as strings.    
   *
   * @param pValue The string value representing the color that should be represented by this {@code ColorParameter} object.
   *
   * @return true, if the color value could be successfully set. False otherwise.
   **/   
  public boolean setValue (String pValue) {
    //1. make a simple check
    if (pValue == null) return false;
    pValue = pValue.trim();
    
    //2. parse pre defined values
    Hashtable<String, Color> pColorMapping = new Hashtable<String, Color>();
    pColorMapping.put("black", Color.BLACK);
    pColorMapping.put("blue", Color.BLUE);
    pColorMapping.put("cyan", Color.CYAN);
    pColorMapping.put("darkgray", Color.DARK_GRAY);
    pColorMapping.put("gray", Color.GRAY);
    pColorMapping.put("green", Color.GREEN);
    pColorMapping.put("lightgray", Color.LIGHT_GRAY);
    pColorMapping.put("magenta", Color.MAGENTA);
    pColorMapping.put("orange", Color.ORANGE);
    pColorMapping.put("pink", Color.PINK);
    pColorMapping.put("red", Color.RED);
    pColorMapping.put("white", Color.WHITE);
    pColorMapping.put("yellow", Color.YELLOW);
    
    Color pColor = pColorMapping.get(pValue.toLowerCase());
    if (pColor != null) {
      setValue(pColor);
      return true;
    }
    
    //3. parse rgb code 255,255,255
    String[] pRGB = pValue.split(",");
    if (pRGB.length != 3) return false;
    
    try {
      int iRed = Integer.parseInt(pRGB[0]);
      int iGreen = Integer.parseInt(pRGB[1]);
      int iBlue = Integer.parseInt(pRGB[2]);
      setValue(new Color(iRed, iGreen, iBlue));
      return true;
    }
    catch (Exception pException) {
      return false;
    }
    

  }


  /////////////////////////
  // GET METHODS         //
  /////////////////////////
  /**
   * Returns the color value that is represented by this {@code ColorParameter} object.
   *
   * @return The color value that is represented by this {@code ColorParameter} object.
   **/   
  public Color getValue() {
    return m_pInterpolationContainer.getValue(0);
  }

  /*
  public ColorChoosePanel getImageEffectGUIElement(String pLabelText) {

    //1. make a simple check
    if (pLabelText == null) pLabelText = "";

    //2. create and return the checkbox
    m_pColorChoosePanel = new ColorChoosePanel(pLabelText, m_pInterpolationContainer.getValue(0));
    m_pColorChoosePanel.addActionListener(this);

    return m_pColorChoosePanel;
  }
  */



  ////////////////////////////////
  // ACTION LISTENER INTERFACE  //
  ////////////////////////////////
  public void actionPerformed(ActionEvent e) {

    //1. make some checks
    /*if (m_pColorChoosePanel == null) return;


    //2. set the value
    m_pInterpolationContainer.setValue(new InterpolatedColor(m_pColorChoosePanel.getColor()), 0);
    */
  }


}
