package standard;

/*
 *  Copyright (C) 2014 Juergen Platzer 
 * 
 *  This file is part of JFXLibrary.
 *  
 *  JFXLibrary is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *  
 *  JFXLibrary is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *  
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with JFXLibrary.  If not, see <http://www.gnu.org/licenses/>.
 */

//java api imports
import java.awt.image.BufferedImage;

/**
 *   This interface should be implemented by all classes that listen to a processing video effect or are waiting
 *   for the end of the execution of a video effect.
 *
 *
 **/
public interface IVideoEffectListener extends IThreadListener {


  /**
   *  Sets the information of the current frame that is processed. 
   *
   *  @param pCurrentFrame The current frame of the video as {@code BufferedImage}. 
   *  @param iFrameId The id of the current frame as integer. 
   *  @param iFrameNumber The total number of frames. 
   **/
  public void setCurrentVideoFrame(BufferedImage pCurrentFrame, int iFrameId, int iFrameNumber);

  /**
   *  Notifies the listener that the processing of the video effect started. 
   **/
  public void processingStarted();
}
